# coding: utf-8
import pprint
import six
from enum import Enum



class RestCurrency:

    swagger_types = {
    
        'currency_code': 'str',
        'fraction_digits': 'int',
        'numeric_code': 'int',
    }

    attribute_map = {
        'currency_code': 'currencyCode','fraction_digits': 'fractionDigits','numeric_code': 'numericCode',
    }

    
    _currency_code = None
    _fraction_digits = None
    _numeric_code = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.currency_code = kwargs.get('currency_code', None)
        self.fraction_digits = kwargs.get('fraction_digits', None)
        self.numeric_code = kwargs.get('numeric_code', None)
        

    
    @property
    def currency_code(self):
        """Gets the currency_code of this RestCurrency.

            The currency code identifies the currency with the three char long ISO 4217 code (e.g. USD, CHF, EUR).

        :return: The currency_code of this RestCurrency.
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this RestCurrency.

            The currency code identifies the currency with the three char long ISO 4217 code (e.g. USD, CHF, EUR).

        :param currency_code: The currency_code of this RestCurrency.
        :type: str
        """

        self._currency_code = currency_code
    
    @property
    def fraction_digits(self):
        """Gets the fraction_digits of this RestCurrency.

            The fraction digits indicates how many places the currency has. This also indicates with which precision we calculate internally when we do calculations with this currency.

        :return: The fraction_digits of this RestCurrency.
        :rtype: int
        """
        return self._fraction_digits

    @fraction_digits.setter
    def fraction_digits(self, fraction_digits):
        """Sets the fraction_digits of this RestCurrency.

            The fraction digits indicates how many places the currency has. This also indicates with which precision we calculate internally when we do calculations with this currency.

        :param fraction_digits: The fraction_digits of this RestCurrency.
        :type: int
        """

        self._fraction_digits = fraction_digits
    
    @property
    def numeric_code(self):
        """Gets the numeric_code of this RestCurrency.

            The numeric code identifies the currency with the three digit long ISO 4217 code (e.g. 978, 756, 840).

        :return: The numeric_code of this RestCurrency.
        :rtype: int
        """
        return self._numeric_code

    @numeric_code.setter
    def numeric_code(self, numeric_code):
        """Sets the numeric_code of this RestCurrency.

            The numeric code identifies the currency with the three digit long ISO 4217 code (e.g. 978, 756, 840).

        :param numeric_code: The numeric_code of this RestCurrency.
        :type: int
        """

        self._numeric_code = numeric_code
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(RestCurrency, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, RestCurrency):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentAppProcessor:

    swagger_types = {
    
        'configured_environment': 'ChargeAttemptEnvironment',
        'created_on': 'datetime',
        'documentation_url': 'str',
        'external_id': 'str',
        'id': 'int',
        'installation_id': 'int',
        'linked_space_id': 'int',
        'name': 'str',
        'processor_configuration': 'PaymentProcessorConfiguration',
        'production_mode_url': 'str',
        'state': 'PaymentAppProcessorState',
        'svg_icon': 'str',
        'updated_on': 'datetime',
        'usable_in_production': 'bool',
        'usable_in_production_since': 'datetime',
        'version': 'int',
    }

    attribute_map = {
        'configured_environment': 'configuredEnvironment','created_on': 'createdOn','documentation_url': 'documentationUrl','external_id': 'externalId','id': 'id','installation_id': 'installationId','linked_space_id': 'linkedSpaceId','name': 'name','processor_configuration': 'processorConfiguration','production_mode_url': 'productionModeUrl','state': 'state','svg_icon': 'svgIcon','updated_on': 'updatedOn','usable_in_production': 'usableInProduction','usable_in_production_since': 'usableInProductionSince','version': 'version',
    }

    
    _configured_environment = None
    _created_on = None
    _documentation_url = None
    _external_id = None
    _id = None
    _installation_id = None
    _linked_space_id = None
    _name = None
    _processor_configuration = None
    _production_mode_url = None
    _state = None
    _svg_icon = None
    _updated_on = None
    _usable_in_production = None
    _usable_in_production_since = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.configured_environment = kwargs.get('configured_environment', None)
        self.created_on = kwargs.get('created_on', None)
        self.documentation_url = kwargs.get('documentation_url', None)
        self.external_id = kwargs.get('external_id', None)
        self.id = kwargs.get('id', None)
        self.installation_id = kwargs.get('installation_id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.name = kwargs.get('name', None)
        self.processor_configuration = kwargs.get('processor_configuration', None)
        self.production_mode_url = kwargs.get('production_mode_url', None)
        self.state = kwargs.get('state', None)
        self.svg_icon = kwargs.get('svg_icon', None)
        self.updated_on = kwargs.get('updated_on', None)
        self.usable_in_production = kwargs.get('usable_in_production', None)
        self.usable_in_production_since = kwargs.get('usable_in_production_since', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def configured_environment(self):
        """Gets the configured_environment of this PaymentAppProcessor.

            

        :return: The configured_environment of this PaymentAppProcessor.
        :rtype: ChargeAttemptEnvironment
        """
        return self._configured_environment

    @configured_environment.setter
    def configured_environment(self, configured_environment):
        """Sets the configured_environment of this PaymentAppProcessor.

            

        :param configured_environment: The configured_environment of this PaymentAppProcessor.
        :type: ChargeAttemptEnvironment
        """

        self._configured_environment = configured_environment
    
    @property
    def created_on(self):
        """Gets the created_on of this PaymentAppProcessor.

            The created on date is the date when this processor has been added.

        :return: The created_on of this PaymentAppProcessor.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this PaymentAppProcessor.

            The created on date is the date when this processor has been added.

        :param created_on: The created_on of this PaymentAppProcessor.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def documentation_url(self):
        """Gets the documentation_url of this PaymentAppProcessor.

            The documentation URL points to a web site that describes how to configure and use the processor.

        :return: The documentation_url of this PaymentAppProcessor.
        :rtype: str
        """
        return self._documentation_url

    @documentation_url.setter
    def documentation_url(self, documentation_url):
        """Sets the documentation_url of this PaymentAppProcessor.

            The documentation URL points to a web site that describes how to configure and use the processor.

        :param documentation_url: The documentation_url of this PaymentAppProcessor.
        :type: str
        """

        self._documentation_url = documentation_url
    
    @property
    def external_id(self):
        """Gets the external_id of this PaymentAppProcessor.

            The external ID corresponds to the ID that was provided during creation of the processor.

        :return: The external_id of this PaymentAppProcessor.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this PaymentAppProcessor.

            The external ID corresponds to the ID that was provided during creation of the processor.

        :param external_id: The external_id of this PaymentAppProcessor.
        :type: str
        """
        if external_id is not None and len(external_id) > 40:
            raise ValueError("Invalid value for `external_id`, length must be less than or equal to `40`")

        self._external_id = external_id
    
    @property
    def id(self):
        """Gets the id of this PaymentAppProcessor.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this PaymentAppProcessor.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentAppProcessor.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this PaymentAppProcessor.
        :type: int
        """

        self._id = id
    
    @property
    def installation_id(self):
        """Gets the installation_id of this PaymentAppProcessor.

            The installation ID identifies the Web App installation.

        :return: The installation_id of this PaymentAppProcessor.
        :rtype: int
        """
        return self._installation_id

    @installation_id.setter
    def installation_id(self, installation_id):
        """Sets the installation_id of this PaymentAppProcessor.

            The installation ID identifies the Web App installation.

        :param installation_id: The installation_id of this PaymentAppProcessor.
        :type: int
        """

        self._installation_id = installation_id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this PaymentAppProcessor.

            The linked space id holds the ID of the space to which the entity belongs to.

        :return: The linked_space_id of this PaymentAppProcessor.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this PaymentAppProcessor.

            The linked space id holds the ID of the space to which the entity belongs to.

        :param linked_space_id: The linked_space_id of this PaymentAppProcessor.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def name(self):
        """Gets the name of this PaymentAppProcessor.

            The name of the processor will be displayed within the user interfaces that the merchant is interacting with.

        :return: The name of this PaymentAppProcessor.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PaymentAppProcessor.

            The name of the processor will be displayed within the user interfaces that the merchant is interacting with.

        :param name: The name of this PaymentAppProcessor.
        :type: str
        """
        if name is not None and len(name) > 100:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")

        self._name = name
    
    @property
    def processor_configuration(self):
        """Gets the processor_configuration of this PaymentAppProcessor.

            This processor configuration is created as part of the app processor. Any transaction created with the processor is linked with this processor configuration.

        :return: The processor_configuration of this PaymentAppProcessor.
        :rtype: PaymentProcessorConfiguration
        """
        return self._processor_configuration

    @processor_configuration.setter
    def processor_configuration(self, processor_configuration):
        """Sets the processor_configuration of this PaymentAppProcessor.

            This processor configuration is created as part of the app processor. Any transaction created with the processor is linked with this processor configuration.

        :param processor_configuration: The processor_configuration of this PaymentAppProcessor.
        :type: PaymentProcessorConfiguration
        """

        self._processor_configuration = processor_configuration
    
    @property
    def production_mode_url(self):
        """Gets the production_mode_url of this PaymentAppProcessor.

            When the user sets the processor into the production mode the user will be forwarded to this URL to configure the production environment. When no URL is provided no redirection will happen.

        :return: The production_mode_url of this PaymentAppProcessor.
        :rtype: str
        """
        return self._production_mode_url

    @production_mode_url.setter
    def production_mode_url(self, production_mode_url):
        """Sets the production_mode_url of this PaymentAppProcessor.

            When the user sets the processor into the production mode the user will be forwarded to this URL to configure the production environment. When no URL is provided no redirection will happen.

        :param production_mode_url: The production_mode_url of this PaymentAppProcessor.
        :type: str
        """

        self._production_mode_url = production_mode_url
    
    @property
    def state(self):
        """Gets the state of this PaymentAppProcessor.

            

        :return: The state of this PaymentAppProcessor.
        :rtype: PaymentAppProcessorState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this PaymentAppProcessor.

            

        :param state: The state of this PaymentAppProcessor.
        :type: PaymentAppProcessorState
        """

        self._state = state
    
    @property
    def svg_icon(self):
        """Gets the svg_icon of this PaymentAppProcessor.

            

        :return: The svg_icon of this PaymentAppProcessor.
        :rtype: str
        """
        return self._svg_icon

    @svg_icon.setter
    def svg_icon(self, svg_icon):
        """Sets the svg_icon of this PaymentAppProcessor.

            

        :param svg_icon: The svg_icon of this PaymentAppProcessor.
        :type: str
        """
        if svg_icon is not None and len(svg_icon) > 10000:
            raise ValueError("Invalid value for `svg_icon`, length must be less than or equal to `10000`")

        self._svg_icon = svg_icon
    
    @property
    def updated_on(self):
        """Gets the updated_on of this PaymentAppProcessor.

            The updated on date indicates when the last update on the processor occurred.

        :return: The updated_on of this PaymentAppProcessor.
        :rtype: datetime
        """
        return self._updated_on

    @updated_on.setter
    def updated_on(self, updated_on):
        """Sets the updated_on of this PaymentAppProcessor.

            The updated on date indicates when the last update on the processor occurred.

        :param updated_on: The updated_on of this PaymentAppProcessor.
        :type: datetime
        """

        self._updated_on = updated_on
    
    @property
    def usable_in_production(self):
        """Gets the usable_in_production of this PaymentAppProcessor.

            When the processor is ready to be used for transactions in the production environment this flag is set to true.

        :return: The usable_in_production of this PaymentAppProcessor.
        :rtype: bool
        """
        return self._usable_in_production

    @usable_in_production.setter
    def usable_in_production(self, usable_in_production):
        """Sets the usable_in_production of this PaymentAppProcessor.

            When the processor is ready to be used for transactions in the production environment this flag is set to true.

        :param usable_in_production: The usable_in_production of this PaymentAppProcessor.
        :type: bool
        """

        self._usable_in_production = usable_in_production
    
    @property
    def usable_in_production_since(self):
        """Gets the usable_in_production_since of this PaymentAppProcessor.

            

        :return: The usable_in_production_since of this PaymentAppProcessor.
        :rtype: datetime
        """
        return self._usable_in_production_since

    @usable_in_production_since.setter
    def usable_in_production_since(self, usable_in_production_since):
        """Sets the usable_in_production_since of this PaymentAppProcessor.

            

        :param usable_in_production_since: The usable_in_production_since of this PaymentAppProcessor.
        :type: datetime
        """

        self._usable_in_production_since = usable_in_production_since
    
    @property
    def version(self):
        """Gets the version of this PaymentAppProcessor.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this PaymentAppProcessor.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PaymentAppProcessor.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this PaymentAppProcessor.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentAppProcessor, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentAppProcessor):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class TwoFactorAuthenticationType:

    swagger_types = {
    
        'description': 'dict(str, str)',
        'feature': 'int',
        'icon': 'str',
        'id': 'int',
        'name': 'dict(str, str)',
    }

    attribute_map = {
        'description': 'description','feature': 'feature','icon': 'icon','id': 'id','name': 'name',
    }

    
    _description = None
    _feature = None
    _icon = None
    _id = None
    _name = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.description = kwargs.get('description', None)
        self.feature = kwargs.get('feature', None)
        self.icon = kwargs.get('icon', None)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        

    
    @property
    def description(self):
        """Gets the description of this TwoFactorAuthenticationType.

            

        :return: The description of this TwoFactorAuthenticationType.
        :rtype: dict(str, str)
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this TwoFactorAuthenticationType.

            

        :param description: The description of this TwoFactorAuthenticationType.
        :type: dict(str, str)
        """

        self._description = description
    
    @property
    def feature(self):
        """Gets the feature of this TwoFactorAuthenticationType.

            

        :return: The feature of this TwoFactorAuthenticationType.
        :rtype: int
        """
        return self._feature

    @feature.setter
    def feature(self, feature):
        """Sets the feature of this TwoFactorAuthenticationType.

            

        :param feature: The feature of this TwoFactorAuthenticationType.
        :type: int
        """

        self._feature = feature
    
    @property
    def icon(self):
        """Gets the icon of this TwoFactorAuthenticationType.

            

        :return: The icon of this TwoFactorAuthenticationType.
        :rtype: str
        """
        return self._icon

    @icon.setter
    def icon(self, icon):
        """Sets the icon of this TwoFactorAuthenticationType.

            

        :param icon: The icon of this TwoFactorAuthenticationType.
        :type: str
        """

        self._icon = icon
    
    @property
    def id(self):
        """Gets the id of this TwoFactorAuthenticationType.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this TwoFactorAuthenticationType.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TwoFactorAuthenticationType.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this TwoFactorAuthenticationType.
        :type: int
        """

        self._id = id
    
    @property
    def name(self):
        """Gets the name of this TwoFactorAuthenticationType.

            

        :return: The name of this TwoFactorAuthenticationType.
        :rtype: dict(str, str)
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TwoFactorAuthenticationType.

            

        :param name: The name of this TwoFactorAuthenticationType.
        :type: dict(str, str)
        """

        self._name = name
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(TwoFactorAuthenticationType, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, TwoFactorAuthenticationType):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class AbstractSpaceUpdate:

    swagger_types = {
    
        'last_modified_date': 'datetime',
        'name': 'str',
        'postal_address': 'SpaceAddressCreate',
        'primary_currency': 'str',
        'request_limit': 'int',
        'state': 'CreationEntityState',
        'technical_contact_addresses': 'list[str]',
        'time_zone': 'str',
    }

    attribute_map = {
        'last_modified_date': 'lastModifiedDate','name': 'name','postal_address': 'postalAddress','primary_currency': 'primaryCurrency','request_limit': 'requestLimit','state': 'state','technical_contact_addresses': 'technicalContactAddresses','time_zone': 'timeZone',
    }

    
    _last_modified_date = None
    _name = None
    _postal_address = None
    _primary_currency = None
    _request_limit = None
    _state = None
    _technical_contact_addresses = None
    _time_zone = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.last_modified_date = kwargs.get('last_modified_date', None)
        self.name = kwargs.get('name', None)
        self.postal_address = kwargs.get('postal_address', None)
        self.primary_currency = kwargs.get('primary_currency', None)
        self.request_limit = kwargs.get('request_limit', None)
        self.state = kwargs.get('state', None)
        self.technical_contact_addresses = kwargs.get('technical_contact_addresses', None)
        self.time_zone = kwargs.get('time_zone', None)
        

    
    @property
    def last_modified_date(self):
        """Gets the last_modified_date of this AbstractSpaceUpdate.

            

        :return: The last_modified_date of this AbstractSpaceUpdate.
        :rtype: datetime
        """
        return self._last_modified_date

    @last_modified_date.setter
    def last_modified_date(self, last_modified_date):
        """Sets the last_modified_date of this AbstractSpaceUpdate.

            

        :param last_modified_date: The last_modified_date of this AbstractSpaceUpdate.
        :type: datetime
        """

        self._last_modified_date = last_modified_date
    
    @property
    def name(self):
        """Gets the name of this AbstractSpaceUpdate.

            The space name is used internally to identify the space in administrative interfaces. For example it is used within search fields and hence it should be distinct and descriptive.

        :return: The name of this AbstractSpaceUpdate.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AbstractSpaceUpdate.

            The space name is used internally to identify the space in administrative interfaces. For example it is used within search fields and hence it should be distinct and descriptive.

        :param name: The name of this AbstractSpaceUpdate.
        :type: str
        """
        if name is not None and len(name) > 200:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `200`")
        if name is not None and len(name) < 3:
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `3`")

        self._name = name
    
    @property
    def postal_address(self):
        """Gets the postal_address of this AbstractSpaceUpdate.

            The address to use in communication with clients for example in email, documents etc.

        :return: The postal_address of this AbstractSpaceUpdate.
        :rtype: SpaceAddressCreate
        """
        return self._postal_address

    @postal_address.setter
    def postal_address(self, postal_address):
        """Sets the postal_address of this AbstractSpaceUpdate.

            The address to use in communication with clients for example in email, documents etc.

        :param postal_address: The postal_address of this AbstractSpaceUpdate.
        :type: SpaceAddressCreate
        """

        self._postal_address = postal_address
    
    @property
    def primary_currency(self):
        """Gets the primary_currency of this AbstractSpaceUpdate.

            This is the currency that is used to display aggregated amounts in the space.

        :return: The primary_currency of this AbstractSpaceUpdate.
        :rtype: str
        """
        return self._primary_currency

    @primary_currency.setter
    def primary_currency(self, primary_currency):
        """Sets the primary_currency of this AbstractSpaceUpdate.

            This is the currency that is used to display aggregated amounts in the space.

        :param primary_currency: The primary_currency of this AbstractSpaceUpdate.
        :type: str
        """

        self._primary_currency = primary_currency
    
    @property
    def request_limit(self):
        """Gets the request_limit of this AbstractSpaceUpdate.

            The request limit defines the maximum number of API request accepted within 2 minutes for this space. This limit can only be changed with special privileges.

        :return: The request_limit of this AbstractSpaceUpdate.
        :rtype: int
        """
        return self._request_limit

    @request_limit.setter
    def request_limit(self, request_limit):
        """Sets the request_limit of this AbstractSpaceUpdate.

            The request limit defines the maximum number of API request accepted within 2 minutes for this space. This limit can only be changed with special privileges.

        :param request_limit: The request_limit of this AbstractSpaceUpdate.
        :type: int
        """

        self._request_limit = request_limit
    
    @property
    def state(self):
        """Gets the state of this AbstractSpaceUpdate.

            

        :return: The state of this AbstractSpaceUpdate.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this AbstractSpaceUpdate.

            

        :param state: The state of this AbstractSpaceUpdate.
        :type: CreationEntityState
        """

        self._state = state
    
    @property
    def technical_contact_addresses(self):
        """Gets the technical_contact_addresses of this AbstractSpaceUpdate.

            The email address provided as contact addresses will be informed about technical issues or errors triggered by the space.

        :return: The technical_contact_addresses of this AbstractSpaceUpdate.
        :rtype: list[str]
        """
        return self._technical_contact_addresses

    @technical_contact_addresses.setter
    def technical_contact_addresses(self, technical_contact_addresses):
        """Sets the technical_contact_addresses of this AbstractSpaceUpdate.

            The email address provided as contact addresses will be informed about technical issues or errors triggered by the space.

        :param technical_contact_addresses: The technical_contact_addresses of this AbstractSpaceUpdate.
        :type: list[str]
        """

        self._technical_contact_addresses = technical_contact_addresses
    
    @property
    def time_zone(self):
        """Gets the time_zone of this AbstractSpaceUpdate.

            The time zone assigned to the space determines the time offset for calculating dates within the space. This is typically used for background processed which needs to be triggered on a specific hour within the day. Changing the space time zone will not change the display of dates.

        :return: The time_zone of this AbstractSpaceUpdate.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this AbstractSpaceUpdate.

            The time zone assigned to the space determines the time offset for calculating dates within the space. This is typically used for background processed which needs to be triggered on a specific hour within the day. Changing the space time zone will not change the display of dates.

        :param time_zone: The time_zone of this AbstractSpaceUpdate.
        :type: str
        """

        self._time_zone = time_zone
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(AbstractSpaceUpdate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, AbstractSpaceUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8

from __future__ import absolute_import

import six

from wallee.api_client import ApiClient

class TransactionTerminalServiceApi:

    def __init__(self, configuration):
        self.api_client = ApiClient(configuration=configuration)

    def fetch_receipts(self, space_id, request, **kwargs):
        """Fetch Receipts

        Returns all receipts for the requested terminal transaction.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fetch_receipts(space_id, request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param TerminalReceiptFetchRequest request:  (required)
        :return: list[RenderedTerminalReceipt]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.fetch_receipts_with_http_info(space_id, request, **kwargs)
        else:
            (data) = self.fetch_receipts_with_http_info(space_id, request, **kwargs)
            return data

    def fetch_receipts_with_http_info(self, space_id, request, **kwargs):
        """Fetch Receipts

        Returns all receipts for the requested terminal transaction.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fetch_receipts_with_http_info(space_id, request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param TerminalReceiptFetchRequest request:  (required)
        :return: list[RenderedTerminalReceipt]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'request']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method fetch_receipts" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `fetch_receipts`")
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `fetch_receipts`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/transaction-terminal/fetch-receipts', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[RenderedTerminalReceipt]',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def till_connection_credentials(self, space_id, transaction_id, terminal_id, **kwargs):
        """Create Till Connection Credentials

        This operation creates a set of credentials to use within the WebSocket.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.till_connection_credentials(space_id, transaction_id, terminal_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int transaction_id: The ID of the transaction which is used to process with the terminal. (required)
        :param int terminal_id: The ID of the terminal which should be used to process the transaction. (required)
        :param str language: The language in which the messages should be rendered in.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.till_connection_credentials_with_http_info(space_id, transaction_id, terminal_id, **kwargs)
        else:
            (data) = self.till_connection_credentials_with_http_info(space_id, transaction_id, terminal_id, **kwargs)
            return data

    def till_connection_credentials_with_http_info(self, space_id, transaction_id, terminal_id, **kwargs):
        """Create Till Connection Credentials

        This operation creates a set of credentials to use within the WebSocket.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.till_connection_credentials_with_http_info(space_id, transaction_id, terminal_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int transaction_id: The ID of the transaction which is used to process with the terminal. (required)
        :param int terminal_id: The ID of the terminal which should be used to process the transaction. (required)
        :param str language: The language in which the messages should be rendered in.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'transaction_id', 'terminal_id', 'language']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method till_connection_credentials" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `till_connection_credentials`")
        # verify the required parameter 'transaction_id' is set
        if ('transaction_id' not in params or
                params['transaction_id'] is None):
            raise ValueError("Missing the required parameter `transaction_id` when calling `till_connection_credentials`")
        # verify the required parameter 'terminal_id' is set
        if ('terminal_id' not in params or
                params['terminal_id'] is None):
            raise ValueError("Missing the required parameter `terminal_id` when calling `till_connection_credentials`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'transaction_id' in params:
            query_params.append(('transactionId', params['transaction_id']))
        if 'terminal_id' in params:
            query_params.append(('terminalId', params['terminal_id']))
        if 'language' in params:
            query_params.append(('language', params['language']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/transaction-terminal/till-connection-credentials', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8
import pprint
import six
from enum import Enum



class SubscriptionLedgerEntry:

    swagger_types = {
    
        'aggregated_tax_rate': 'float',
        'amount_excluding_tax': 'float',
        'amount_including_tax': 'float',
        'created_by': 'int',
        'created_on': 'datetime',
        'discount_including_tax': 'float',
        'external_id': 'str',
        'id': 'int',
        'linked_space_id': 'int',
        'planned_purge_date': 'datetime',
        'quantity': 'float',
        'state': 'SubscriptionLedgerEntryState',
        'subscription_version': 'int',
        'tax_amount': 'float',
        'taxes': 'list[Tax]',
        'title': 'str',
        'version': 'int',
    }

    attribute_map = {
        'aggregated_tax_rate': 'aggregatedTaxRate','amount_excluding_tax': 'amountExcludingTax','amount_including_tax': 'amountIncludingTax','created_by': 'createdBy','created_on': 'createdOn','discount_including_tax': 'discountIncludingTax','external_id': 'externalId','id': 'id','linked_space_id': 'linkedSpaceId','planned_purge_date': 'plannedPurgeDate','quantity': 'quantity','state': 'state','subscription_version': 'subscriptionVersion','tax_amount': 'taxAmount','taxes': 'taxes','title': 'title','version': 'version',
    }

    
    _aggregated_tax_rate = None
    _amount_excluding_tax = None
    _amount_including_tax = None
    _created_by = None
    _created_on = None
    _discount_including_tax = None
    _external_id = None
    _id = None
    _linked_space_id = None
    _planned_purge_date = None
    _quantity = None
    _state = None
    _subscription_version = None
    _tax_amount = None
    _taxes = None
    _title = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.aggregated_tax_rate = kwargs.get('aggregated_tax_rate', None)
        self.amount_excluding_tax = kwargs.get('amount_excluding_tax', None)
        self.amount_including_tax = kwargs.get('amount_including_tax', None)
        self.created_by = kwargs.get('created_by', None)
        self.created_on = kwargs.get('created_on', None)
        self.discount_including_tax = kwargs.get('discount_including_tax', None)
        self.external_id = kwargs.get('external_id', None)
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.quantity = kwargs.get('quantity', None)
        self.state = kwargs.get('state', None)
        self.subscription_version = kwargs.get('subscription_version', None)
        self.tax_amount = kwargs.get('tax_amount', None)
        self.taxes = kwargs.get('taxes', None)
        self.title = kwargs.get('title', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def aggregated_tax_rate(self):
        """Gets the aggregated_tax_rate of this SubscriptionLedgerEntry.

            

        :return: The aggregated_tax_rate of this SubscriptionLedgerEntry.
        :rtype: float
        """
        return self._aggregated_tax_rate

    @aggregated_tax_rate.setter
    def aggregated_tax_rate(self, aggregated_tax_rate):
        """Sets the aggregated_tax_rate of this SubscriptionLedgerEntry.

            

        :param aggregated_tax_rate: The aggregated_tax_rate of this SubscriptionLedgerEntry.
        :type: float
        """

        self._aggregated_tax_rate = aggregated_tax_rate
    
    @property
    def amount_excluding_tax(self):
        """Gets the amount_excluding_tax of this SubscriptionLedgerEntry.

            

        :return: The amount_excluding_tax of this SubscriptionLedgerEntry.
        :rtype: float
        """
        return self._amount_excluding_tax

    @amount_excluding_tax.setter
    def amount_excluding_tax(self, amount_excluding_tax):
        """Sets the amount_excluding_tax of this SubscriptionLedgerEntry.

            

        :param amount_excluding_tax: The amount_excluding_tax of this SubscriptionLedgerEntry.
        :type: float
        """

        self._amount_excluding_tax = amount_excluding_tax
    
    @property
    def amount_including_tax(self):
        """Gets the amount_including_tax of this SubscriptionLedgerEntry.

            

        :return: The amount_including_tax of this SubscriptionLedgerEntry.
        :rtype: float
        """
        return self._amount_including_tax

    @amount_including_tax.setter
    def amount_including_tax(self, amount_including_tax):
        """Sets the amount_including_tax of this SubscriptionLedgerEntry.

            

        :param amount_including_tax: The amount_including_tax of this SubscriptionLedgerEntry.
        :type: float
        """

        self._amount_including_tax = amount_including_tax
    
    @property
    def created_by(self):
        """Gets the created_by of this SubscriptionLedgerEntry.

            

        :return: The created_by of this SubscriptionLedgerEntry.
        :rtype: int
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this SubscriptionLedgerEntry.

            

        :param created_by: The created_by of this SubscriptionLedgerEntry.
        :type: int
        """

        self._created_by = created_by
    
    @property
    def created_on(self):
        """Gets the created_on of this SubscriptionLedgerEntry.

            The created on date indicates the date on which the entity was stored into the database.

        :return: The created_on of this SubscriptionLedgerEntry.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this SubscriptionLedgerEntry.

            The created on date indicates the date on which the entity was stored into the database.

        :param created_on: The created_on of this SubscriptionLedgerEntry.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def discount_including_tax(self):
        """Gets the discount_including_tax of this SubscriptionLedgerEntry.

            

        :return: The discount_including_tax of this SubscriptionLedgerEntry.
        :rtype: float
        """
        return self._discount_including_tax

    @discount_including_tax.setter
    def discount_including_tax(self, discount_including_tax):
        """Sets the discount_including_tax of this SubscriptionLedgerEntry.

            

        :param discount_including_tax: The discount_including_tax of this SubscriptionLedgerEntry.
        :type: float
        """

        self._discount_including_tax = discount_including_tax
    
    @property
    def external_id(self):
        """Gets the external_id of this SubscriptionLedgerEntry.

            A client generated nonce which identifies the entity to be created. Subsequent creation requests with the same external ID will not create new entities but return the initially created entity instead.

        :return: The external_id of this SubscriptionLedgerEntry.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this SubscriptionLedgerEntry.

            A client generated nonce which identifies the entity to be created. Subsequent creation requests with the same external ID will not create new entities but return the initially created entity instead.

        :param external_id: The external_id of this SubscriptionLedgerEntry.
        :type: str
        """

        self._external_id = external_id
    
    @property
    def id(self):
        """Gets the id of this SubscriptionLedgerEntry.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this SubscriptionLedgerEntry.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SubscriptionLedgerEntry.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this SubscriptionLedgerEntry.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this SubscriptionLedgerEntry.

            The linked space id holds the ID of the space to which the entity belongs to.

        :return: The linked_space_id of this SubscriptionLedgerEntry.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this SubscriptionLedgerEntry.

            The linked space id holds the ID of the space to which the entity belongs to.

        :param linked_space_id: The linked_space_id of this SubscriptionLedgerEntry.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this SubscriptionLedgerEntry.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :return: The planned_purge_date of this SubscriptionLedgerEntry.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this SubscriptionLedgerEntry.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :param planned_purge_date: The planned_purge_date of this SubscriptionLedgerEntry.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def quantity(self):
        """Gets the quantity of this SubscriptionLedgerEntry.

            

        :return: The quantity of this SubscriptionLedgerEntry.
        :rtype: float
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this SubscriptionLedgerEntry.

            

        :param quantity: The quantity of this SubscriptionLedgerEntry.
        :type: float
        """

        self._quantity = quantity
    
    @property
    def state(self):
        """Gets the state of this SubscriptionLedgerEntry.

            

        :return: The state of this SubscriptionLedgerEntry.
        :rtype: SubscriptionLedgerEntryState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this SubscriptionLedgerEntry.

            

        :param state: The state of this SubscriptionLedgerEntry.
        :type: SubscriptionLedgerEntryState
        """

        self._state = state
    
    @property
    def subscription_version(self):
        """Gets the subscription_version of this SubscriptionLedgerEntry.

            

        :return: The subscription_version of this SubscriptionLedgerEntry.
        :rtype: int
        """
        return self._subscription_version

    @subscription_version.setter
    def subscription_version(self, subscription_version):
        """Sets the subscription_version of this SubscriptionLedgerEntry.

            

        :param subscription_version: The subscription_version of this SubscriptionLedgerEntry.
        :type: int
        """

        self._subscription_version = subscription_version
    
    @property
    def tax_amount(self):
        """Gets the tax_amount of this SubscriptionLedgerEntry.

            

        :return: The tax_amount of this SubscriptionLedgerEntry.
        :rtype: float
        """
        return self._tax_amount

    @tax_amount.setter
    def tax_amount(self, tax_amount):
        """Sets the tax_amount of this SubscriptionLedgerEntry.

            

        :param tax_amount: The tax_amount of this SubscriptionLedgerEntry.
        :type: float
        """

        self._tax_amount = tax_amount
    
    @property
    def taxes(self):
        """Gets the taxes of this SubscriptionLedgerEntry.

            

        :return: The taxes of this SubscriptionLedgerEntry.
        :rtype: list[Tax]
        """
        return self._taxes

    @taxes.setter
    def taxes(self, taxes):
        """Sets the taxes of this SubscriptionLedgerEntry.

            

        :param taxes: The taxes of this SubscriptionLedgerEntry.
        :type: list[Tax]
        """

        self._taxes = taxes
    
    @property
    def title(self):
        """Gets the title of this SubscriptionLedgerEntry.

            

        :return: The title of this SubscriptionLedgerEntry.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this SubscriptionLedgerEntry.

            

        :param title: The title of this SubscriptionLedgerEntry.
        :type: str
        """
        if title is not None and len(title) > 150:
            raise ValueError("Invalid value for `title`, length must be less than or equal to `150`")
        if title is not None and len(title) < 1:
            raise ValueError("Invalid value for `title`, length must be greater than or equal to `1`")

        self._title = title
    
    @property
    def version(self):
        """Gets the version of this SubscriptionLedgerEntry.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this SubscriptionLedgerEntry.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this SubscriptionLedgerEntry.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this SubscriptionLedgerEntry.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(SubscriptionLedgerEntry, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, SubscriptionLedgerEntry):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentContract:

    swagger_types = {
    
        'account': 'Account',
        'activated_on': 'datetime',
        'contract_identifier': 'str',
        'contract_type': 'PaymentContractType',
        'created_by': 'User',
        'created_on': 'datetime',
        'external_id': 'str',
        'id': 'int',
        'rejected_on': 'datetime',
        'rejection_reason': 'FailureReason',
        'start_terminating_on': 'datetime',
        'state': 'PaymentContractState',
        'terminated_by': 'User',
        'terminated_on': 'datetime',
        'version': 'int',
    }

    attribute_map = {
        'account': 'account','activated_on': 'activatedOn','contract_identifier': 'contractIdentifier','contract_type': 'contractType','created_by': 'createdBy','created_on': 'createdOn','external_id': 'externalId','id': 'id','rejected_on': 'rejectedOn','rejection_reason': 'rejectionReason','start_terminating_on': 'startTerminatingOn','state': 'state','terminated_by': 'terminatedBy','terminated_on': 'terminatedOn','version': 'version',
    }

    
    _account = None
    _activated_on = None
    _contract_identifier = None
    _contract_type = None
    _created_by = None
    _created_on = None
    _external_id = None
    _id = None
    _rejected_on = None
    _rejection_reason = None
    _start_terminating_on = None
    _state = None
    _terminated_by = None
    _terminated_on = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.account = kwargs.get('account', None)
        self.activated_on = kwargs.get('activated_on', None)
        self.contract_identifier = kwargs.get('contract_identifier', None)
        self.contract_type = kwargs.get('contract_type', None)
        self.created_by = kwargs.get('created_by', None)
        self.created_on = kwargs.get('created_on', None)
        self.external_id = kwargs.get('external_id', None)
        self.id = kwargs.get('id', None)
        self.rejected_on = kwargs.get('rejected_on', None)
        self.rejection_reason = kwargs.get('rejection_reason', None)
        self.start_terminating_on = kwargs.get('start_terminating_on', None)
        self.state = kwargs.get('state', None)
        self.terminated_by = kwargs.get('terminated_by', None)
        self.terminated_on = kwargs.get('terminated_on', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def account(self):
        """Gets the account of this PaymentContract.

            

        :return: The account of this PaymentContract.
        :rtype: Account
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this PaymentContract.

            

        :param account: The account of this PaymentContract.
        :type: Account
        """

        self._account = account
    
    @property
    def activated_on(self):
        """Gets the activated_on of this PaymentContract.

            

        :return: The activated_on of this PaymentContract.
        :rtype: datetime
        """
        return self._activated_on

    @activated_on.setter
    def activated_on(self, activated_on):
        """Sets the activated_on of this PaymentContract.

            

        :param activated_on: The activated_on of this PaymentContract.
        :type: datetime
        """

        self._activated_on = activated_on
    
    @property
    def contract_identifier(self):
        """Gets the contract_identifier of this PaymentContract.

            

        :return: The contract_identifier of this PaymentContract.
        :rtype: str
        """
        return self._contract_identifier

    @contract_identifier.setter
    def contract_identifier(self, contract_identifier):
        """Sets the contract_identifier of this PaymentContract.

            

        :param contract_identifier: The contract_identifier of this PaymentContract.
        :type: str
        """

        self._contract_identifier = contract_identifier
    
    @property
    def contract_type(self):
        """Gets the contract_type of this PaymentContract.

            

        :return: The contract_type of this PaymentContract.
        :rtype: PaymentContractType
        """
        return self._contract_type

    @contract_type.setter
    def contract_type(self, contract_type):
        """Sets the contract_type of this PaymentContract.

            

        :param contract_type: The contract_type of this PaymentContract.
        :type: PaymentContractType
        """

        self._contract_type = contract_type
    
    @property
    def created_by(self):
        """Gets the created_by of this PaymentContract.

            

        :return: The created_by of this PaymentContract.
        :rtype: User
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this PaymentContract.

            

        :param created_by: The created_by of this PaymentContract.
        :type: User
        """

        self._created_by = created_by
    
    @property
    def created_on(self):
        """Gets the created_on of this PaymentContract.

            The created on date indicates the date on which the entity was stored into the database.

        :return: The created_on of this PaymentContract.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this PaymentContract.

            The created on date indicates the date on which the entity was stored into the database.

        :param created_on: The created_on of this PaymentContract.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def external_id(self):
        """Gets the external_id of this PaymentContract.

            A client generated nonce which identifies the entity to be created. Subsequent creation requests with the same external ID will not create new entities but return the initially created entity instead.

        :return: The external_id of this PaymentContract.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this PaymentContract.

            A client generated nonce which identifies the entity to be created. Subsequent creation requests with the same external ID will not create new entities but return the initially created entity instead.

        :param external_id: The external_id of this PaymentContract.
        :type: str
        """

        self._external_id = external_id
    
    @property
    def id(self):
        """Gets the id of this PaymentContract.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this PaymentContract.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentContract.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this PaymentContract.
        :type: int
        """

        self._id = id
    
    @property
    def rejected_on(self):
        """Gets the rejected_on of this PaymentContract.

            

        :return: The rejected_on of this PaymentContract.
        :rtype: datetime
        """
        return self._rejected_on

    @rejected_on.setter
    def rejected_on(self, rejected_on):
        """Sets the rejected_on of this PaymentContract.

            

        :param rejected_on: The rejected_on of this PaymentContract.
        :type: datetime
        """

        self._rejected_on = rejected_on
    
    @property
    def rejection_reason(self):
        """Gets the rejection_reason of this PaymentContract.

            

        :return: The rejection_reason of this PaymentContract.
        :rtype: FailureReason
        """
        return self._rejection_reason

    @rejection_reason.setter
    def rejection_reason(self, rejection_reason):
        """Sets the rejection_reason of this PaymentContract.

            

        :param rejection_reason: The rejection_reason of this PaymentContract.
        :type: FailureReason
        """

        self._rejection_reason = rejection_reason
    
    @property
    def start_terminating_on(self):
        """Gets the start_terminating_on of this PaymentContract.

            

        :return: The start_terminating_on of this PaymentContract.
        :rtype: datetime
        """
        return self._start_terminating_on

    @start_terminating_on.setter
    def start_terminating_on(self, start_terminating_on):
        """Sets the start_terminating_on of this PaymentContract.

            

        :param start_terminating_on: The start_terminating_on of this PaymentContract.
        :type: datetime
        """

        self._start_terminating_on = start_terminating_on
    
    @property
    def state(self):
        """Gets the state of this PaymentContract.

            

        :return: The state of this PaymentContract.
        :rtype: PaymentContractState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this PaymentContract.

            

        :param state: The state of this PaymentContract.
        :type: PaymentContractState
        """

        self._state = state
    
    @property
    def terminated_by(self):
        """Gets the terminated_by of this PaymentContract.

            

        :return: The terminated_by of this PaymentContract.
        :rtype: User
        """
        return self._terminated_by

    @terminated_by.setter
    def terminated_by(self, terminated_by):
        """Sets the terminated_by of this PaymentContract.

            

        :param terminated_by: The terminated_by of this PaymentContract.
        :type: User
        """

        self._terminated_by = terminated_by
    
    @property
    def terminated_on(self):
        """Gets the terminated_on of this PaymentContract.

            

        :return: The terminated_on of this PaymentContract.
        :rtype: datetime
        """
        return self._terminated_on

    @terminated_on.setter
    def terminated_on(self, terminated_on):
        """Sets the terminated_on of this PaymentContract.

            

        :param terminated_on: The terminated_on of this PaymentContract.
        :type: datetime
        """

        self._terminated_on = terminated_on
    
    @property
    def version(self):
        """Gets the version of this PaymentContract.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this PaymentContract.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PaymentContract.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this PaymentContract.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentContract, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentContract):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8

from __future__ import absolute_import

import six

from wallee.api_client import ApiClient

class WebAppServiceApi:

    def __init__(self, configuration):
        self.api_client = ApiClient(configuration=configuration)

    def check_installation(self, space_id, **kwargs):
        """Check Installation

        This operation returns true when the app is installed in given space. The web app is implied by the client ID resp. user ID that is been used to invoke this operation.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.check_installation(space_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id: This parameter identifies the space which should be checked if the web app is installed. (required)
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.check_installation_with_http_info(space_id, **kwargs)
        else:
            (data) = self.check_installation_with_http_info(space_id, **kwargs)
            return data

    def check_installation_with_http_info(self, space_id, **kwargs):
        """Check Installation

        This operation returns true when the app is installed in given space. The web app is implied by the client ID resp. user ID that is been used to invoke this operation.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.check_installation_with_http_info(space_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id: This parameter identifies the space which should be checked if the web app is installed. (required)
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method check_installation" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `check_installation`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/web-app/check-installation', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def confirm(self, request, **kwargs):
        """Confirm

        This operation confirms the app installation. This method has to be invoked after the user returns to the web app. The request of the user will contain the code as a request parameter. The web app is implied by the client ID resp. user ID that is been used to invoke this operation.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.confirm(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param WebAppConfirmationRequest request:  (required)
        :return: WebAppConfirmationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.confirm_with_http_info(request, **kwargs)
        else:
            (data) = self.confirm_with_http_info(request, **kwargs)
            return data

    def confirm_with_http_info(self, request, **kwargs):
        """Confirm

        This operation confirms the app installation. This method has to be invoked after the user returns to the web app. The request of the user will contain the code as a request parameter. The web app is implied by the client ID resp. user ID that is been used to invoke this operation.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.confirm_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param WebAppConfirmationRequest request:  (required)
        :return: WebAppConfirmationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['request']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method confirm" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `confirm`")

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/web-app/confirm', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WebAppConfirmationResponse',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def uninstall(self, space_id, **kwargs):
        """Uninstall

        This operation uninstalls the web app from the provided space. The web app is implied by the client ID resp. user ID that is been used to invoke this operation.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.uninstall(space_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id: This parameter identifies the space within which the web app should be uninstalled. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.uninstall_with_http_info(space_id, **kwargs)
        else:
            (data) = self.uninstall_with_http_info(space_id, **kwargs)
            return data

    def uninstall_with_http_info(self, space_id, **kwargs):
        """Uninstall

        This operation uninstalls the web app from the provided space. The web app is implied by the client ID resp. user ID that is been used to invoke this operation.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.uninstall_with_http_info(space_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id: This parameter identifies the space within which the web app should be uninstalled. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method uninstall" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `uninstall`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/web-app/uninstall', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8
import pprint
import six
from enum import Enum



class InstallmentPayment:

    swagger_types = {
    
        'created_on': 'datetime',
        'id': 'int',
        'initial_transaction': 'Transaction',
        'line_items': 'list[LineItem]',
        'linked_space_id': 'int',
        'plan_configuration': 'int',
        'planned_purge_date': 'datetime',
        'state': 'InstallmentPaymentState',
        'version': 'int',
    }

    attribute_map = {
        'created_on': 'createdOn','id': 'id','initial_transaction': 'initialTransaction','line_items': 'lineItems','linked_space_id': 'linkedSpaceId','plan_configuration': 'planConfiguration','planned_purge_date': 'plannedPurgeDate','state': 'state','version': 'version',
    }

    
    _created_on = None
    _id = None
    _initial_transaction = None
    _line_items = None
    _linked_space_id = None
    _plan_configuration = None
    _planned_purge_date = None
    _state = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.created_on = kwargs.get('created_on', None)
        self.id = kwargs.get('id', None)
        self.initial_transaction = kwargs.get('initial_transaction', None)
        self.line_items = kwargs.get('line_items', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.plan_configuration = kwargs.get('plan_configuration', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.state = kwargs.get('state', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def created_on(self):
        """Gets the created_on of this InstallmentPayment.

            The created on date indicates the date on which the entity was stored into the database.

        :return: The created_on of this InstallmentPayment.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this InstallmentPayment.

            The created on date indicates the date on which the entity was stored into the database.

        :param created_on: The created_on of this InstallmentPayment.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def id(self):
        """Gets the id of this InstallmentPayment.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this InstallmentPayment.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InstallmentPayment.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this InstallmentPayment.
        :type: int
        """

        self._id = id
    
    @property
    def initial_transaction(self):
        """Gets the initial_transaction of this InstallmentPayment.

            

        :return: The initial_transaction of this InstallmentPayment.
        :rtype: Transaction
        """
        return self._initial_transaction

    @initial_transaction.setter
    def initial_transaction(self, initial_transaction):
        """Sets the initial_transaction of this InstallmentPayment.

            

        :param initial_transaction: The initial_transaction of this InstallmentPayment.
        :type: Transaction
        """

        self._initial_transaction = initial_transaction
    
    @property
    def line_items(self):
        """Gets the line_items of this InstallmentPayment.

            

        :return: The line_items of this InstallmentPayment.
        :rtype: list[LineItem]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this InstallmentPayment.

            

        :param line_items: The line_items of this InstallmentPayment.
        :type: list[LineItem]
        """

        self._line_items = line_items
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this InstallmentPayment.

            The linked space id holds the ID of the space to which the entity belongs to.

        :return: The linked_space_id of this InstallmentPayment.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this InstallmentPayment.

            The linked space id holds the ID of the space to which the entity belongs to.

        :param linked_space_id: The linked_space_id of this InstallmentPayment.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def plan_configuration(self):
        """Gets the plan_configuration of this InstallmentPayment.

            

        :return: The plan_configuration of this InstallmentPayment.
        :rtype: int
        """
        return self._plan_configuration

    @plan_configuration.setter
    def plan_configuration(self, plan_configuration):
        """Sets the plan_configuration of this InstallmentPayment.

            

        :param plan_configuration: The plan_configuration of this InstallmentPayment.
        :type: int
        """

        self._plan_configuration = plan_configuration
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this InstallmentPayment.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :return: The planned_purge_date of this InstallmentPayment.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this InstallmentPayment.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :param planned_purge_date: The planned_purge_date of this InstallmentPayment.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def state(self):
        """Gets the state of this InstallmentPayment.

            

        :return: The state of this InstallmentPayment.
        :rtype: InstallmentPaymentState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this InstallmentPayment.

            

        :param state: The state of this InstallmentPayment.
        :type: InstallmentPaymentState
        """

        self._state = state
    
    @property
    def version(self):
        """Gets the version of this InstallmentPayment.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this InstallmentPayment.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this InstallmentPayment.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this InstallmentPayment.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(InstallmentPayment, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, InstallmentPayment):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class SubscriptionProductComponent:

    swagger_types = {
    
        'component_change_weight': 'int',
        'component_group': 'SubscriptionProductComponentGroup',
        'default_component': 'bool',
        'description': 'DatabaseTranslatedString',
        'id': 'int',
        'linked_space_id': 'int',
        'maximal_quantity': 'float',
        'minimal_quantity': 'float',
        'name': 'DatabaseTranslatedString',
        'quantity_step': 'float',
        'reference': 'SubscriptionProductComponentReference',
        'sort_order': 'int',
        'tax_class': 'TaxClass',
        'version': 'int',
    }

    attribute_map = {
        'component_change_weight': 'componentChangeWeight','component_group': 'componentGroup','default_component': 'defaultComponent','description': 'description','id': 'id','linked_space_id': 'linkedSpaceId','maximal_quantity': 'maximalQuantity','minimal_quantity': 'minimalQuantity','name': 'name','quantity_step': 'quantityStep','reference': 'reference','sort_order': 'sortOrder','tax_class': 'taxClass','version': 'version',
    }

    
    _component_change_weight = None
    _component_group = None
    _default_component = None
    _description = None
    _id = None
    _linked_space_id = None
    _maximal_quantity = None
    _minimal_quantity = None
    _name = None
    _quantity_step = None
    _reference = None
    _sort_order = None
    _tax_class = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.component_change_weight = kwargs.get('component_change_weight', None)
        self.component_group = kwargs.get('component_group', None)
        self.default_component = kwargs.get('default_component', None)
        self.description = kwargs.get('description', None)
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.maximal_quantity = kwargs.get('maximal_quantity', None)
        self.minimal_quantity = kwargs.get('minimal_quantity', None)
        self.name = kwargs.get('name', None)
        self.quantity_step = kwargs.get('quantity_step', None)
        self.reference = kwargs.get('reference', None)
        self.sort_order = kwargs.get('sort_order', None)
        self.tax_class = kwargs.get('tax_class', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def component_change_weight(self):
        """Gets the component_change_weight of this SubscriptionProductComponent.

            If a product component changes from one with a lower product component tier (e.g. 1) to one with a higher product component tier (e.g. 3), it is considered an upgrade and a one-time fee could be applied.

        :return: The component_change_weight of this SubscriptionProductComponent.
        :rtype: int
        """
        return self._component_change_weight

    @component_change_weight.setter
    def component_change_weight(self, component_change_weight):
        """Sets the component_change_weight of this SubscriptionProductComponent.

            If a product component changes from one with a lower product component tier (e.g. 1) to one with a higher product component tier (e.g. 3), it is considered an upgrade and a one-time fee could be applied.

        :param component_change_weight: The component_change_weight of this SubscriptionProductComponent.
        :type: int
        """

        self._component_change_weight = component_change_weight
    
    @property
    def component_group(self):
        """Gets the component_group of this SubscriptionProductComponent.

            

        :return: The component_group of this SubscriptionProductComponent.
        :rtype: SubscriptionProductComponentGroup
        """
        return self._component_group

    @component_group.setter
    def component_group(self, component_group):
        """Sets the component_group of this SubscriptionProductComponent.

            

        :param component_group: The component_group of this SubscriptionProductComponent.
        :type: SubscriptionProductComponentGroup
        """

        self._component_group = component_group
    
    @property
    def default_component(self):
        """Gets the default_component of this SubscriptionProductComponent.

            When a component is marked as a 'default' component it is used as the default component in its group and will be preselected in the product configuration.

        :return: The default_component of this SubscriptionProductComponent.
        :rtype: bool
        """
        return self._default_component

    @default_component.setter
    def default_component(self, default_component):
        """Sets the default_component of this SubscriptionProductComponent.

            When a component is marked as a 'default' component it is used as the default component in its group and will be preselected in the product configuration.

        :param default_component: The default_component of this SubscriptionProductComponent.
        :type: bool
        """

        self._default_component = default_component
    
    @property
    def description(self):
        """Gets the description of this SubscriptionProductComponent.

            The component description may contain a longer description which gives the subscriber a better understanding of what the component contains.

        :return: The description of this SubscriptionProductComponent.
        :rtype: DatabaseTranslatedString
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this SubscriptionProductComponent.

            The component description may contain a longer description which gives the subscriber a better understanding of what the component contains.

        :param description: The description of this SubscriptionProductComponent.
        :type: DatabaseTranslatedString
        """

        self._description = description
    
    @property
    def id(self):
        """Gets the id of this SubscriptionProductComponent.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this SubscriptionProductComponent.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SubscriptionProductComponent.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this SubscriptionProductComponent.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this SubscriptionProductComponent.

            The linked space id holds the ID of the space to which the entity belongs to.

        :return: The linked_space_id of this SubscriptionProductComponent.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this SubscriptionProductComponent.

            The linked space id holds the ID of the space to which the entity belongs to.

        :param linked_space_id: The linked_space_id of this SubscriptionProductComponent.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def maximal_quantity(self):
        """Gets the maximal_quantity of this SubscriptionProductComponent.

            The maximum quantity defines the maximum value which must be entered for the quantity.

        :return: The maximal_quantity of this SubscriptionProductComponent.
        :rtype: float
        """
        return self._maximal_quantity

    @maximal_quantity.setter
    def maximal_quantity(self, maximal_quantity):
        """Sets the maximal_quantity of this SubscriptionProductComponent.

            The maximum quantity defines the maximum value which must be entered for the quantity.

        :param maximal_quantity: The maximal_quantity of this SubscriptionProductComponent.
        :type: float
        """

        self._maximal_quantity = maximal_quantity
    
    @property
    def minimal_quantity(self):
        """Gets the minimal_quantity of this SubscriptionProductComponent.

            The minimal quantity defines the minimum value which must be entered for the quantity.

        :return: The minimal_quantity of this SubscriptionProductComponent.
        :rtype: float
        """
        return self._minimal_quantity

    @minimal_quantity.setter
    def minimal_quantity(self, minimal_quantity):
        """Sets the minimal_quantity of this SubscriptionProductComponent.

            The minimal quantity defines the minimum value which must be entered for the quantity.

        :param minimal_quantity: The minimal_quantity of this SubscriptionProductComponent.
        :type: float
        """

        self._minimal_quantity = minimal_quantity
    
    @property
    def name(self):
        """Gets the name of this SubscriptionProductComponent.

            The component name is shown to the subscriber. It should describe in few words what the component does contain.

        :return: The name of this SubscriptionProductComponent.
        :rtype: DatabaseTranslatedString
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SubscriptionProductComponent.

            The component name is shown to the subscriber. It should describe in few words what the component does contain.

        :param name: The name of this SubscriptionProductComponent.
        :type: DatabaseTranslatedString
        """

        self._name = name
    
    @property
    def quantity_step(self):
        """Gets the quantity_step of this SubscriptionProductComponent.

            The quantity step defines at which interval the quantity can be increased.

        :return: The quantity_step of this SubscriptionProductComponent.
        :rtype: float
        """
        return self._quantity_step

    @quantity_step.setter
    def quantity_step(self, quantity_step):
        """Sets the quantity_step of this SubscriptionProductComponent.

            The quantity step defines at which interval the quantity can be increased.

        :param quantity_step: The quantity_step of this SubscriptionProductComponent.
        :type: float
        """

        self._quantity_step = quantity_step
    
    @property
    def reference(self):
        """Gets the reference of this SubscriptionProductComponent.

            The component reference is used to identify the component by external systems and it marks components to represent the same component within different product versions.

        :return: The reference of this SubscriptionProductComponent.
        :rtype: SubscriptionProductComponentReference
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this SubscriptionProductComponent.

            The component reference is used to identify the component by external systems and it marks components to represent the same component within different product versions.

        :param reference: The reference of this SubscriptionProductComponent.
        :type: SubscriptionProductComponentReference
        """

        self._reference = reference
    
    @property
    def sort_order(self):
        """Gets the sort_order of this SubscriptionProductComponent.

            The sort order controls in which order the component is listed. The sort order is used to order the components in ascending order.

        :return: The sort_order of this SubscriptionProductComponent.
        :rtype: int
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this SubscriptionProductComponent.

            The sort order controls in which order the component is listed. The sort order is used to order the components in ascending order.

        :param sort_order: The sort_order of this SubscriptionProductComponent.
        :type: int
        """

        self._sort_order = sort_order
    
    @property
    def tax_class(self):
        """Gets the tax_class of this SubscriptionProductComponent.

            The tax class of the component determines the taxes which are applicable on all fees linked with the component.

        :return: The tax_class of this SubscriptionProductComponent.
        :rtype: TaxClass
        """
        return self._tax_class

    @tax_class.setter
    def tax_class(self, tax_class):
        """Sets the tax_class of this SubscriptionProductComponent.

            The tax class of the component determines the taxes which are applicable on all fees linked with the component.

        :param tax_class: The tax_class of this SubscriptionProductComponent.
        :type: TaxClass
        """

        self._tax_class = tax_class
    
    @property
    def version(self):
        """Gets the version of this SubscriptionProductComponent.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this SubscriptionProductComponent.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this SubscriptionProductComponent.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this SubscriptionProductComponent.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(SubscriptionProductComponent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, SubscriptionProductComponent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class TransactionUserInterfaceType(Enum):
    
    IFRAME = "IFRAME"
    LIGHTBOX = "LIGHTBOX"
    PAYMENT_PAGE = "PAYMENT_PAGE"
    MOBILE_SDK = "MOBILE_SDK"
    TERMINAL = "TERMINAL"




# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentInitiationAdviceFile:

    swagger_types = {
    
        'created_on': 'datetime',
        'file_generated_on': 'datetime',
        'id': 'int',
        'linked_space_id': 'int',
        'name': 'str',
        'processed_on': 'datetime',
        'processor': 'PaymentProcessor',
        'state': 'PaymentInitiationAdviceFileState',
    }

    attribute_map = {
        'created_on': 'createdOn','file_generated_on': 'fileGeneratedOn','id': 'id','linked_space_id': 'linkedSpaceId','name': 'name','processed_on': 'processedOn','processor': 'processor','state': 'state',
    }

    
    _created_on = None
    _file_generated_on = None
    _id = None
    _linked_space_id = None
    _name = None
    _processed_on = None
    _processor = None
    _state = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.created_on = kwargs.get('created_on', None)
        self.file_generated_on = kwargs.get('file_generated_on', None)
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.name = kwargs.get('name', None)
        self.processed_on = kwargs.get('processed_on', None)
        self.processor = kwargs.get('processor', None)
        self.state = kwargs.get('state', None)
        

    
    @property
    def created_on(self):
        """Gets the created_on of this PaymentInitiationAdviceFile.

            The created on date indicates the date on which the entity was stored into the database.

        :return: The created_on of this PaymentInitiationAdviceFile.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this PaymentInitiationAdviceFile.

            The created on date indicates the date on which the entity was stored into the database.

        :param created_on: The created_on of this PaymentInitiationAdviceFile.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def file_generated_on(self):
        """Gets the file_generated_on of this PaymentInitiationAdviceFile.

            

        :return: The file_generated_on of this PaymentInitiationAdviceFile.
        :rtype: datetime
        """
        return self._file_generated_on

    @file_generated_on.setter
    def file_generated_on(self, file_generated_on):
        """Sets the file_generated_on of this PaymentInitiationAdviceFile.

            

        :param file_generated_on: The file_generated_on of this PaymentInitiationAdviceFile.
        :type: datetime
        """

        self._file_generated_on = file_generated_on
    
    @property
    def id(self):
        """Gets the id of this PaymentInitiationAdviceFile.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this PaymentInitiationAdviceFile.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentInitiationAdviceFile.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this PaymentInitiationAdviceFile.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this PaymentInitiationAdviceFile.

            The linked space id holds the ID of the space to which the entity belongs to.

        :return: The linked_space_id of this PaymentInitiationAdviceFile.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this PaymentInitiationAdviceFile.

            The linked space id holds the ID of the space to which the entity belongs to.

        :param linked_space_id: The linked_space_id of this PaymentInitiationAdviceFile.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def name(self):
        """Gets the name of this PaymentInitiationAdviceFile.

            

        :return: The name of this PaymentInitiationAdviceFile.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PaymentInitiationAdviceFile.

            

        :param name: The name of this PaymentInitiationAdviceFile.
        :type: str
        """

        self._name = name
    
    @property
    def processed_on(self):
        """Gets the processed_on of this PaymentInitiationAdviceFile.

            

        :return: The processed_on of this PaymentInitiationAdviceFile.
        :rtype: datetime
        """
        return self._processed_on

    @processed_on.setter
    def processed_on(self, processed_on):
        """Sets the processed_on of this PaymentInitiationAdviceFile.

            

        :param processed_on: The processed_on of this PaymentInitiationAdviceFile.
        :type: datetime
        """

        self._processed_on = processed_on
    
    @property
    def processor(self):
        """Gets the processor of this PaymentInitiationAdviceFile.

            

        :return: The processor of this PaymentInitiationAdviceFile.
        :rtype: PaymentProcessor
        """
        return self._processor

    @processor.setter
    def processor(self, processor):
        """Sets the processor of this PaymentInitiationAdviceFile.

            

        :param processor: The processor of this PaymentInitiationAdviceFile.
        :type: PaymentProcessor
        """

        self._processor = processor
    
    @property
    def state(self):
        """Gets the state of this PaymentInitiationAdviceFile.

            

        :return: The state of this PaymentInitiationAdviceFile.
        :rtype: PaymentInitiationAdviceFileState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this PaymentInitiationAdviceFile.

            

        :param state: The state of this PaymentInitiationAdviceFile.
        :type: PaymentInitiationAdviceFileState
        """

        self._state = state
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentInitiationAdviceFile, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentInitiationAdviceFile):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum
from . import TransactionAwareEntity


class Charge(TransactionAwareEntity):

    swagger_types = {
    
        'created_on': 'datetime',
        'failure_reason': 'FailureReason',
        'language': 'str',
        'planned_purge_date': 'datetime',
        'space_view_id': 'int',
        'state': 'ChargeState',
        'time_zone': 'str',
        'timeout_on': 'datetime',
        'transaction': 'Transaction',
        'type': 'ChargeType',
        'user_failure_message': 'str',
        'version': 'int',
    }

    attribute_map = {
        'created_on': 'createdOn','failure_reason': 'failureReason','language': 'language','planned_purge_date': 'plannedPurgeDate','space_view_id': 'spaceViewId','state': 'state','time_zone': 'timeZone','timeout_on': 'timeoutOn','transaction': 'transaction','type': 'type','user_failure_message': 'userFailureMessage','version': 'version',
    }

    
    _created_on = None
    _failure_reason = None
    _language = None
    _planned_purge_date = None
    _space_view_id = None
    _state = None
    _time_zone = None
    _timeout_on = None
    _transaction = None
    _type = None
    _user_failure_message = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.created_on = kwargs.get('created_on', None)
        self.failure_reason = kwargs.get('failure_reason', None)
        self.language = kwargs.get('language', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.space_view_id = kwargs.get('space_view_id', None)
        self.state = kwargs.get('state', None)
        self.time_zone = kwargs.get('time_zone', None)
        self.timeout_on = kwargs.get('timeout_on', None)
        self.transaction = kwargs.get('transaction', None)
        self.type = kwargs.get('type', None)
        self.user_failure_message = kwargs.get('user_failure_message', None)
        self.version = kwargs.get('version', None)
        super().__init__(**kwargs)
        self.swagger_types.update(super().swagger_types)
        self.attribute_map.update(super().attribute_map)

    
    @property
    def created_on(self):
        """Gets the created_on of this Charge.

            The date on which the charge was created on.

        :return: The created_on of this Charge.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this Charge.

            The date on which the charge was created on.

        :param created_on: The created_on of this Charge.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def failure_reason(self):
        """Gets the failure_reason of this Charge.

            

        :return: The failure_reason of this Charge.
        :rtype: FailureReason
        """
        return self._failure_reason

    @failure_reason.setter
    def failure_reason(self, failure_reason):
        """Sets the failure_reason of this Charge.

            

        :param failure_reason: The failure_reason of this Charge.
        :type: FailureReason
        """

        self._failure_reason = failure_reason
    
    @property
    def language(self):
        """Gets the language of this Charge.

            

        :return: The language of this Charge.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this Charge.

            

        :param language: The language of this Charge.
        :type: str
        """

        self._language = language
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this Charge.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :return: The planned_purge_date of this Charge.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this Charge.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :param planned_purge_date: The planned_purge_date of this Charge.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def space_view_id(self):
        """Gets the space_view_id of this Charge.

            

        :return: The space_view_id of this Charge.
        :rtype: int
        """
        return self._space_view_id

    @space_view_id.setter
    def space_view_id(self, space_view_id):
        """Sets the space_view_id of this Charge.

            

        :param space_view_id: The space_view_id of this Charge.
        :type: int
        """

        self._space_view_id = space_view_id
    
    @property
    def state(self):
        """Gets the state of this Charge.

            

        :return: The state of this Charge.
        :rtype: ChargeState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Charge.

            

        :param state: The state of this Charge.
        :type: ChargeState
        """

        self._state = state
    
    @property
    def time_zone(self):
        """Gets the time_zone of this Charge.

            

        :return: The time_zone of this Charge.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this Charge.

            

        :param time_zone: The time_zone of this Charge.
        :type: str
        """

        self._time_zone = time_zone
    
    @property
    def timeout_on(self):
        """Gets the timeout_on of this Charge.

            

        :return: The timeout_on of this Charge.
        :rtype: datetime
        """
        return self._timeout_on

    @timeout_on.setter
    def timeout_on(self, timeout_on):
        """Sets the timeout_on of this Charge.

            

        :param timeout_on: The timeout_on of this Charge.
        :type: datetime
        """

        self._timeout_on = timeout_on
    
    @property
    def transaction(self):
        """Gets the transaction of this Charge.

            

        :return: The transaction of this Charge.
        :rtype: Transaction
        """
        return self._transaction

    @transaction.setter
    def transaction(self, transaction):
        """Sets the transaction of this Charge.

            

        :param transaction: The transaction of this Charge.
        :type: Transaction
        """

        self._transaction = transaction
    
    @property
    def type(self):
        """Gets the type of this Charge.

            

        :return: The type of this Charge.
        :rtype: ChargeType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Charge.

            

        :param type: The type of this Charge.
        :type: ChargeType
        """

        self._type = type
    
    @property
    def user_failure_message(self):
        """Gets the user_failure_message of this Charge.

            The failure message describes for an end user why the charge is failed in the language of the user. This is only provided when the charge is marked as failed.

        :return: The user_failure_message of this Charge.
        :rtype: str
        """
        return self._user_failure_message

    @user_failure_message.setter
    def user_failure_message(self, user_failure_message):
        """Sets the user_failure_message of this Charge.

            The failure message describes for an end user why the charge is failed in the language of the user. This is only provided when the charge is marked as failed.

        :param user_failure_message: The user_failure_message of this Charge.
        :type: str
        """

        self._user_failure_message = user_failure_message
    
    @property
    def version(self):
        """Gets the version of this Charge.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this Charge.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Charge.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this Charge.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(Charge, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, Charge):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class AbstractAccountUpdate:

    swagger_types = {
    
        'last_modified_date': 'datetime',
        'name': 'str',
        'subaccount_limit': 'int',
    }

    attribute_map = {
        'last_modified_date': 'lastModifiedDate','name': 'name','subaccount_limit': 'subaccountLimit',
    }

    
    _last_modified_date = None
    _name = None
    _subaccount_limit = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.last_modified_date = kwargs.get('last_modified_date', None)
        self.name = kwargs.get('name', None)
        self.subaccount_limit = kwargs.get('subaccount_limit', None)
        

    
    @property
    def last_modified_date(self):
        """Gets the last_modified_date of this AbstractAccountUpdate.

            

        :return: The last_modified_date of this AbstractAccountUpdate.
        :rtype: datetime
        """
        return self._last_modified_date

    @last_modified_date.setter
    def last_modified_date(self, last_modified_date):
        """Sets the last_modified_date of this AbstractAccountUpdate.

            

        :param last_modified_date: The last_modified_date of this AbstractAccountUpdate.
        :type: datetime
        """

        self._last_modified_date = last_modified_date
    
    @property
    def name(self):
        """Gets the name of this AbstractAccountUpdate.

            The name of the account identifies the account within the administrative interface.

        :return: The name of this AbstractAccountUpdate.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AbstractAccountUpdate.

            The name of the account identifies the account within the administrative interface.

        :param name: The name of this AbstractAccountUpdate.
        :type: str
        """
        if name is not None and len(name) > 200:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `200`")
        if name is not None and len(name) < 3:
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `3`")

        self._name = name
    
    @property
    def subaccount_limit(self):
        """Gets the subaccount_limit of this AbstractAccountUpdate.

            This property restricts the number of subaccounts which can be created within this account.

        :return: The subaccount_limit of this AbstractAccountUpdate.
        :rtype: int
        """
        return self._subaccount_limit

    @subaccount_limit.setter
    def subaccount_limit(self, subaccount_limit):
        """Sets the subaccount_limit of this AbstractAccountUpdate.

            This property restricts the number of subaccounts which can be created within this account.

        :param subaccount_limit: The subaccount_limit of this AbstractAccountUpdate.
        :type: int
        """

        self._subaccount_limit = subaccount_limit
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(AbstractAccountUpdate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, AbstractAccountUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class WebhookListener:

    swagger_types = {
    
        'entity': 'int',
        'entity_states': 'list[str]',
        'id': 'int',
        'identity': 'WebhookIdentity',
        'linked_space_id': 'int',
        'name': 'str',
        'notify_every_change': 'bool',
        'planned_purge_date': 'datetime',
        'state': 'CreationEntityState',
        'url': 'WebhookUrl',
        'version': 'int',
    }

    attribute_map = {
        'entity': 'entity','entity_states': 'entityStates','id': 'id','identity': 'identity','linked_space_id': 'linkedSpaceId','name': 'name','notify_every_change': 'notifyEveryChange','planned_purge_date': 'plannedPurgeDate','state': 'state','url': 'url','version': 'version',
    }

    
    _entity = None
    _entity_states = None
    _id = None
    _identity = None
    _linked_space_id = None
    _name = None
    _notify_every_change = None
    _planned_purge_date = None
    _state = None
    _url = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.entity = kwargs.get('entity', None)
        self.entity_states = kwargs.get('entity_states', None)
        self.id = kwargs.get('id', None)
        self.identity = kwargs.get('identity', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.name = kwargs.get('name', None)
        self.notify_every_change = kwargs.get('notify_every_change', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.state = kwargs.get('state', None)
        self.url = kwargs.get('url', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def entity(self):
        """Gets the entity of this WebhookListener.

            The listener listens on state changes of the entity linked with the listener.

        :return: The entity of this WebhookListener.
        :rtype: int
        """
        return self._entity

    @entity.setter
    def entity(self, entity):
        """Sets the entity of this WebhookListener.

            The listener listens on state changes of the entity linked with the listener.

        :param entity: The entity of this WebhookListener.
        :type: int
        """

        self._entity = entity
    
    @property
    def entity_states(self):
        """Gets the entity_states of this WebhookListener.

            The target state identifies the state into which entities need to move into to trigger the webhook listener.

        :return: The entity_states of this WebhookListener.
        :rtype: list[str]
        """
        return self._entity_states

    @entity_states.setter
    def entity_states(self, entity_states):
        """Sets the entity_states of this WebhookListener.

            The target state identifies the state into which entities need to move into to trigger the webhook listener.

        :param entity_states: The entity_states of this WebhookListener.
        :type: list[str]
        """

        self._entity_states = entity_states
    
    @property
    def id(self):
        """Gets the id of this WebhookListener.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this WebhookListener.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this WebhookListener.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this WebhookListener.
        :type: int
        """

        self._id = id
    
    @property
    def identity(self):
        """Gets the identity of this WebhookListener.

            The identity which will be used to sign messages sent by this listener.

        :return: The identity of this WebhookListener.
        :rtype: WebhookIdentity
        """
        return self._identity

    @identity.setter
    def identity(self, identity):
        """Sets the identity of this WebhookListener.

            The identity which will be used to sign messages sent by this listener.

        :param identity: The identity of this WebhookListener.
        :type: WebhookIdentity
        """

        self._identity = identity
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this WebhookListener.

            The linked space id holds the ID of the space to which the entity belongs to.

        :return: The linked_space_id of this WebhookListener.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this WebhookListener.

            The linked space id holds the ID of the space to which the entity belongs to.

        :param linked_space_id: The linked_space_id of this WebhookListener.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def name(self):
        """Gets the name of this WebhookListener.

            The webhook listener name is used internally to identify the webhook listener in administrative interfaces.For example it is used within search fields and hence it should be distinct and descriptive.

        :return: The name of this WebhookListener.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this WebhookListener.

            The webhook listener name is used internally to identify the webhook listener in administrative interfaces.For example it is used within search fields and hence it should be distinct and descriptive.

        :param name: The name of this WebhookListener.
        :type: str
        """
        if name is not None and len(name) > 50:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `50`")

        self._name = name
    
    @property
    def notify_every_change(self):
        """Gets the notify_every_change of this WebhookListener.

            Defines whether the webhook listener is to be informed about every change made to the entity in contrast to state transitions only.

        :return: The notify_every_change of this WebhookListener.
        :rtype: bool
        """
        return self._notify_every_change

    @notify_every_change.setter
    def notify_every_change(self, notify_every_change):
        """Sets the notify_every_change of this WebhookListener.

            Defines whether the webhook listener is to be informed about every change made to the entity in contrast to state transitions only.

        :param notify_every_change: The notify_every_change of this WebhookListener.
        :type: bool
        """

        self._notify_every_change = notify_every_change
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this WebhookListener.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :return: The planned_purge_date of this WebhookListener.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this WebhookListener.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :param planned_purge_date: The planned_purge_date of this WebhookListener.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def state(self):
        """Gets the state of this WebhookListener.

            

        :return: The state of this WebhookListener.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this WebhookListener.

            

        :param state: The state of this WebhookListener.
        :type: CreationEntityState
        """

        self._state = state
    
    @property
    def url(self):
        """Gets the url of this WebhookListener.

            The URL which is invoked by the listener to notify the application about the event.

        :return: The url of this WebhookListener.
        :rtype: WebhookUrl
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this WebhookListener.

            The URL which is invoked by the listener to notify the application about the event.

        :param url: The url of this WebhookListener.
        :type: WebhookUrl
        """

        self._url = url
    
    @property
    def version(self):
        """Gets the version of this WebhookListener.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this WebhookListener.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this WebhookListener.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this WebhookListener.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(WebhookListener, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, WebhookListener):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class SubscriptionComponentConfiguration:

    swagger_types = {
    
        'component': 'int',
        'quantity': 'float',
    }

    attribute_map = {
        'component': 'component','quantity': 'quantity',
    }

    
    _component = None
    _quantity = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.component = kwargs.get('component', None)
        self.quantity = kwargs.get('quantity', None)
        

    
    @property
    def component(self):
        """Gets the component of this SubscriptionComponentConfiguration.

            

        :return: The component of this SubscriptionComponentConfiguration.
        :rtype: int
        """
        return self._component

    @component.setter
    def component(self, component):
        """Sets the component of this SubscriptionComponentConfiguration.

            

        :param component: The component of this SubscriptionComponentConfiguration.
        :type: int
        """

        self._component = component
    
    @property
    def quantity(self):
        """Gets the quantity of this SubscriptionComponentConfiguration.

            

        :return: The quantity of this SubscriptionComponentConfiguration.
        :rtype: float
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this SubscriptionComponentConfiguration.

            

        :param quantity: The quantity of this SubscriptionComponentConfiguration.
        :type: float
        """

        self._quantity = quantity
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(SubscriptionComponentConfiguration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, SubscriptionComponentConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentAppChargeAttemptUpdateRequest:

    swagger_types = {
    
        'charge_attempt_id': 'int',
        'end_user_failure_message': 'str',
        'failure_reason_id': 'int',
        'reference': 'str',
        'target_state': 'PaymentAppChargeAttemptTargetState',
    }

    attribute_map = {
        'charge_attempt_id': 'chargeAttemptId','end_user_failure_message': 'endUserFailureMessage','failure_reason_id': 'failureReasonId','reference': 'reference','target_state': 'targetState',
    }

    
    _charge_attempt_id = None
    _end_user_failure_message = None
    _failure_reason_id = None
    _reference = None
    _target_state = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.charge_attempt_id = kwargs.get('charge_attempt_id', None)
        self.end_user_failure_message = kwargs.get('end_user_failure_message', None)
        self.failure_reason_id = kwargs.get('failure_reason_id', None)
        self.reference = kwargs.get('reference', None)
        self.target_state = kwargs.get('target_state', None)
        

    
    @property
    def charge_attempt_id(self):
        """Gets the charge_attempt_id of this PaymentAppChargeAttemptUpdateRequest.

            This is the ID of the charge attempt that should be updated.

        :return: The charge_attempt_id of this PaymentAppChargeAttemptUpdateRequest.
        :rtype: int
        """
        return self._charge_attempt_id

    @charge_attempt_id.setter
    def charge_attempt_id(self, charge_attempt_id):
        """Sets the charge_attempt_id of this PaymentAppChargeAttemptUpdateRequest.

            This is the ID of the charge attempt that should be updated.

        :param charge_attempt_id: The charge_attempt_id of this PaymentAppChargeAttemptUpdateRequest.
        :type: int
        """

        self._charge_attempt_id = charge_attempt_id
    
    @property
    def end_user_failure_message(self):
        """Gets the end_user_failure_message of this PaymentAppChargeAttemptUpdateRequest.

            The end user failure message indicates to the end user (buyer) why the payment failed. The message has to be in the language of the end user. The language is provided within the payment page invocation URL.

        :return: The end_user_failure_message of this PaymentAppChargeAttemptUpdateRequest.
        :rtype: str
        """
        return self._end_user_failure_message

    @end_user_failure_message.setter
    def end_user_failure_message(self, end_user_failure_message):
        """Sets the end_user_failure_message of this PaymentAppChargeAttemptUpdateRequest.

            The end user failure message indicates to the end user (buyer) why the payment failed. The message has to be in the language of the end user. The language is provided within the payment page invocation URL.

        :param end_user_failure_message: The end_user_failure_message of this PaymentAppChargeAttemptUpdateRequest.
        :type: str
        """
        if end_user_failure_message is not None and len(end_user_failure_message) > 2000:
            raise ValueError("Invalid value for `end_user_failure_message`, length must be less than or equal to `2000`")

        self._end_user_failure_message = end_user_failure_message
    
    @property
    def failure_reason_id(self):
        """Gets the failure_reason_id of this PaymentAppChargeAttemptUpdateRequest.

            The failure reason indicates why the charge attempt failed. It is required when the target state is FAILED.

        :return: The failure_reason_id of this PaymentAppChargeAttemptUpdateRequest.
        :rtype: int
        """
        return self._failure_reason_id

    @failure_reason_id.setter
    def failure_reason_id(self, failure_reason_id):
        """Sets the failure_reason_id of this PaymentAppChargeAttemptUpdateRequest.

            The failure reason indicates why the charge attempt failed. It is required when the target state is FAILED.

        :param failure_reason_id: The failure_reason_id of this PaymentAppChargeAttemptUpdateRequest.
        :type: int
        """

        self._failure_reason_id = failure_reason_id
    
    @property
    def reference(self):
        """Gets the reference of this PaymentAppChargeAttemptUpdateRequest.

            The reference identifies the charge attempt within the systems of the external service provider. It is required when the target state is SUCCESSFUL.

        :return: The reference of this PaymentAppChargeAttemptUpdateRequest.
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this PaymentAppChargeAttemptUpdateRequest.

            The reference identifies the charge attempt within the systems of the external service provider. It is required when the target state is SUCCESSFUL.

        :param reference: The reference of this PaymentAppChargeAttemptUpdateRequest.
        :type: str
        """
        if reference is not None and len(reference) > 100:
            raise ValueError("Invalid value for `reference`, length must be less than or equal to `100`")

        self._reference = reference
    
    @property
    def target_state(self):
        """Gets the target_state of this PaymentAppChargeAttemptUpdateRequest.

            The target state defines the state into which the charge attempt should be switched into. Once the charge attempt changed the state it will not be possible to change it again.

        :return: The target_state of this PaymentAppChargeAttemptUpdateRequest.
        :rtype: PaymentAppChargeAttemptTargetState
        """
        return self._target_state

    @target_state.setter
    def target_state(self, target_state):
        """Sets the target_state of this PaymentAppChargeAttemptUpdateRequest.

            The target state defines the state into which the charge attempt should be switched into. Once the charge attempt changed the state it will not be possible to change it again.

        :param target_state: The target_state of this PaymentAppChargeAttemptUpdateRequest.
        :type: PaymentAppChargeAttemptTargetState
        """

        self._target_state = target_state
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentAppChargeAttemptUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentAppChargeAttemptUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class ShopifySubscriptionModelBillingConfiguration:

    swagger_types = {
    
        'billing_day_of_month': 'int',
        'billing_interval_amount': 'int',
        'billing_interval_unit': 'ShopifySubscriptionBillingIntervalUnit',
        'billing_reference_date': 'datetime',
        'billing_weekday': 'ShopifySubscriptionWeekday',
        'maximal_billing_cycles': 'int',
        'maximal_suspendable_cycles': 'int',
        'minimal_billing_cycles': 'int',
        'termination_billing_cycles': 'int',
    }

    attribute_map = {
        'billing_day_of_month': 'billingDayOfMonth','billing_interval_amount': 'billingIntervalAmount','billing_interval_unit': 'billingIntervalUnit','billing_reference_date': 'billingReferenceDate','billing_weekday': 'billingWeekday','maximal_billing_cycles': 'maximalBillingCycles','maximal_suspendable_cycles': 'maximalSuspendableCycles','minimal_billing_cycles': 'minimalBillingCycles','termination_billing_cycles': 'terminationBillingCycles',
    }

    
    _billing_day_of_month = None
    _billing_interval_amount = None
    _billing_interval_unit = None
    _billing_reference_date = None
    _billing_weekday = None
    _maximal_billing_cycles = None
    _maximal_suspendable_cycles = None
    _minimal_billing_cycles = None
    _termination_billing_cycles = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.billing_day_of_month = kwargs.get('billing_day_of_month', None)
        self.billing_interval_amount = kwargs.get('billing_interval_amount', None)
        self.billing_interval_unit = kwargs.get('billing_interval_unit', None)
        self.billing_reference_date = kwargs.get('billing_reference_date', None)
        self.billing_weekday = kwargs.get('billing_weekday', None)
        self.maximal_billing_cycles = kwargs.get('maximal_billing_cycles', None)
        self.maximal_suspendable_cycles = kwargs.get('maximal_suspendable_cycles', None)
        self.minimal_billing_cycles = kwargs.get('minimal_billing_cycles', None)
        self.termination_billing_cycles = kwargs.get('termination_billing_cycles', None)
        

    
    @property
    def billing_day_of_month(self):
        """Gets the billing_day_of_month of this ShopifySubscriptionModelBillingConfiguration.

            Define the day of the month on which the recurring orders should be created.

        :return: The billing_day_of_month of this ShopifySubscriptionModelBillingConfiguration.
        :rtype: int
        """
        return self._billing_day_of_month

    @billing_day_of_month.setter
    def billing_day_of_month(self, billing_day_of_month):
        """Sets the billing_day_of_month of this ShopifySubscriptionModelBillingConfiguration.

            Define the day of the month on which the recurring orders should be created.

        :param billing_day_of_month: The billing_day_of_month of this ShopifySubscriptionModelBillingConfiguration.
        :type: int
        """

        self._billing_day_of_month = billing_day_of_month
    
    @property
    def billing_interval_amount(self):
        """Gets the billing_interval_amount of this ShopifySubscriptionModelBillingConfiguration.

            

        :return: The billing_interval_amount of this ShopifySubscriptionModelBillingConfiguration.
        :rtype: int
        """
        return self._billing_interval_amount

    @billing_interval_amount.setter
    def billing_interval_amount(self, billing_interval_amount):
        """Sets the billing_interval_amount of this ShopifySubscriptionModelBillingConfiguration.

            

        :param billing_interval_amount: The billing_interval_amount of this ShopifySubscriptionModelBillingConfiguration.
        :type: int
        """

        self._billing_interval_amount = billing_interval_amount
    
    @property
    def billing_interval_unit(self):
        """Gets the billing_interval_unit of this ShopifySubscriptionModelBillingConfiguration.

            Define how frequently recurring orders should be created.

        :return: The billing_interval_unit of this ShopifySubscriptionModelBillingConfiguration.
        :rtype: ShopifySubscriptionBillingIntervalUnit
        """
        return self._billing_interval_unit

    @billing_interval_unit.setter
    def billing_interval_unit(self, billing_interval_unit):
        """Sets the billing_interval_unit of this ShopifySubscriptionModelBillingConfiguration.

            Define how frequently recurring orders should be created.

        :param billing_interval_unit: The billing_interval_unit of this ShopifySubscriptionModelBillingConfiguration.
        :type: ShopifySubscriptionBillingIntervalUnit
        """

        self._billing_interval_unit = billing_interval_unit
    
    @property
    def billing_reference_date(self):
        """Gets the billing_reference_date of this ShopifySubscriptionModelBillingConfiguration.

            This date will be used as basis to calculate the dates of recurring orders.

        :return: The billing_reference_date of this ShopifySubscriptionModelBillingConfiguration.
        :rtype: datetime
        """
        return self._billing_reference_date

    @billing_reference_date.setter
    def billing_reference_date(self, billing_reference_date):
        """Sets the billing_reference_date of this ShopifySubscriptionModelBillingConfiguration.

            This date will be used as basis to calculate the dates of recurring orders.

        :param billing_reference_date: The billing_reference_date of this ShopifySubscriptionModelBillingConfiguration.
        :type: datetime
        """

        self._billing_reference_date = billing_reference_date
    
    @property
    def billing_weekday(self):
        """Gets the billing_weekday of this ShopifySubscriptionModelBillingConfiguration.

            Define the weekday on which the recurring orders should be created.

        :return: The billing_weekday of this ShopifySubscriptionModelBillingConfiguration.
        :rtype: ShopifySubscriptionWeekday
        """
        return self._billing_weekday

    @billing_weekday.setter
    def billing_weekday(self, billing_weekday):
        """Sets the billing_weekday of this ShopifySubscriptionModelBillingConfiguration.

            Define the weekday on which the recurring orders should be created.

        :param billing_weekday: The billing_weekday of this ShopifySubscriptionModelBillingConfiguration.
        :type: ShopifySubscriptionWeekday
        """

        self._billing_weekday = billing_weekday
    
    @property
    def maximal_billing_cycles(self):
        """Gets the maximal_billing_cycles of this ShopifySubscriptionModelBillingConfiguration.

            Define the maximum number of orders the subscription will run for.

        :return: The maximal_billing_cycles of this ShopifySubscriptionModelBillingConfiguration.
        :rtype: int
        """
        return self._maximal_billing_cycles

    @maximal_billing_cycles.setter
    def maximal_billing_cycles(self, maximal_billing_cycles):
        """Sets the maximal_billing_cycles of this ShopifySubscriptionModelBillingConfiguration.

            Define the maximum number of orders the subscription will run for.

        :param maximal_billing_cycles: The maximal_billing_cycles of this ShopifySubscriptionModelBillingConfiguration.
        :type: int
        """

        self._maximal_billing_cycles = maximal_billing_cycles
    
    @property
    def maximal_suspendable_cycles(self):
        """Gets the maximal_suspendable_cycles of this ShopifySubscriptionModelBillingConfiguration.

            Define the maximum number of orders the subscription can be suspended for at a time.

        :return: The maximal_suspendable_cycles of this ShopifySubscriptionModelBillingConfiguration.
        :rtype: int
        """
        return self._maximal_suspendable_cycles

    @maximal_suspendable_cycles.setter
    def maximal_suspendable_cycles(self, maximal_suspendable_cycles):
        """Sets the maximal_suspendable_cycles of this ShopifySubscriptionModelBillingConfiguration.

            Define the maximum number of orders the subscription can be suspended for at a time.

        :param maximal_suspendable_cycles: The maximal_suspendable_cycles of this ShopifySubscriptionModelBillingConfiguration.
        :type: int
        """

        self._maximal_suspendable_cycles = maximal_suspendable_cycles
    
    @property
    def minimal_billing_cycles(self):
        """Gets the minimal_billing_cycles of this ShopifySubscriptionModelBillingConfiguration.

            Define the minimal number of orders the subscription will run for.

        :return: The minimal_billing_cycles of this ShopifySubscriptionModelBillingConfiguration.
        :rtype: int
        """
        return self._minimal_billing_cycles

    @minimal_billing_cycles.setter
    def minimal_billing_cycles(self, minimal_billing_cycles):
        """Sets the minimal_billing_cycles of this ShopifySubscriptionModelBillingConfiguration.

            Define the minimal number of orders the subscription will run for.

        :param minimal_billing_cycles: The minimal_billing_cycles of this ShopifySubscriptionModelBillingConfiguration.
        :type: int
        """

        self._minimal_billing_cycles = minimal_billing_cycles
    
    @property
    def termination_billing_cycles(self):
        """Gets the termination_billing_cycles of this ShopifySubscriptionModelBillingConfiguration.

            Define the number of orders the subscription will keep running for after its termination has been requested.

        :return: The termination_billing_cycles of this ShopifySubscriptionModelBillingConfiguration.
        :rtype: int
        """
        return self._termination_billing_cycles

    @termination_billing_cycles.setter
    def termination_billing_cycles(self, termination_billing_cycles):
        """Sets the termination_billing_cycles of this ShopifySubscriptionModelBillingConfiguration.

            Define the number of orders the subscription will keep running for after its termination has been requested.

        :param termination_billing_cycles: The termination_billing_cycles of this ShopifySubscriptionModelBillingConfiguration.
        :type: int
        """

        self._termination_billing_cycles = termination_billing_cycles
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ShopifySubscriptionModelBillingConfiguration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ShopifySubscriptionModelBillingConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
